@@ -2,26 +2,18 @@
 # -*- coding: utf-8 -*-
 
 from .common import _findRawContent
-
-def _parseDomain(url):
-	if not url:
-		return 
-	if not url.startswith('http'):
-		return
-	r = '/'.join(url.split('/')[:3])
-	if r.count('/') == 2 and 'http' in r:
-		return r
+from telegram_util import parseDomain
 
 def _findDomain(soup, url):
 	for meta in soup.find_all('meta'):
 		for att in meta.attrs:
 			if 'url' in att.lower():
-				r = _parseDomain(meta[att])
+				r = parseDomain(meta[att])
 				if r:
 					return r
 	for meta in soup.find_all('meta'):
 		if 'url' in str(meta).lower():
-			r = _parseDomain(_findRawContent(meta))
+			r = parseDomain(_findRawContent(meta))
 			if r:
 				return r
-	return _parseDomain(url)
\ No newline at end of file
+	return parseDomain(url)
\ No newline at end of file
