@@ -38,6 +38,7 @@ def _getInnerArticle_(soup, domain):
 		lambda x: x.find("div", class_ = "post-body"),
 		lambda x: x.find("div", class_ = "mainContent"),
 		lambda x: x.find("div", class_ = "pane-node-body"),
+		lambda x: x.find("div", class_ = "info-content"),
 	]
 	domain_specific_applicators = {
 		'': [lambda x: x.find("body")],
@@ -61,6 +62,9 @@ def _getInnerArticle_(soup, domain):
 		'twreporter.org':[lambda x: x.find("div", {"id" : "article-body"}),],
 		'bbc.co.uk': [lambda x: x.find("div", {"dir": "ltr"})],
 		'bbc.com': [lambda x: x.find("article"), lambda x: x.find("main")],
+		'equalityrights.hku.hk': [lambda x: x.find("article")],
+		'biede.com': [lambda x: x.find("div", class_ = 'lay'),],
+		'www.thewechatproject.org': [lambda x: x.find("div", class_ = 'post-content__body'),],
 	}
 	is_short = matchKey(soup.text, SHORT_ARTICLE)
 	text_limit = 150 if is_short else 500
