@@ -7,10 +7,10 @@ from .images import _yieldPossibleImg
 from bs4 import Comment
 import sys
 
-OFFTOPIC_TAG = ['small', 'address', 'meta', 'script', 'sup']
+OFFTOPIC_TAG = ['small', 'address', 'meta', 'script', 'sup', 'svg']
 
 OFFTOPIC_ATT = [
-	'latest', 'more', 'button', 'facebook',
+	'latest', 'more', 'facebook',
 	'cn-carousel-medium-strip', 'video__end-slate__top-wrapper', 'metadata', 
 	'el__article--embed', 'signup', 'related', 'disclaimer', 'off-screen', 
 	'story-body__unordered-list', 'story-image-copyright', 'article-header', 
@@ -31,16 +31,17 @@ OFFTOPIC_ATT = [
 	'taglist', 'donate', 'see-also', 'donation-box', 'license__Container',
 	'field-photo-credit', 'Avatar', 'floating-share', 'meta-box', 'tag-list',
 	'tools__ShareIconBlock', 'aside__Container', 'MetadataAndTool', 'DesktopAsideBlock',
-	'StyledSeparationCurve'
+	'StyledSeparationCurve', 'separation-curve', "['extending']"
 ]
 
 OFFTOPIC_ATT_WITH_EXCEPTION = {
 	'sidebar': ['no-sidebar', 'one-sidebar', 'penci-main', 'id : page', 
 		'single-post', 'has-sidebar', 'sidebar-off'],
-	'hidden': ['lazy', 'false', 'label-hidden', 'rich_media_content', 'start', 'overflow'],
-	'navigation': ['navigation-border-thin-decoration'],
+	'hidden': ['lazy', 'false', 'label-hidden', 'rich_media_content', 'start', 'overflow', 'comment-hidden', 'ariahidden'],
+	'navigation': ['navigation-', '-navigation'],
 	'copyright': ['and'],
-	'navbar': ['single-post']
+	'navbar': ['single-post'],
+	'button': ['image-container', 'imageViewer', 'tabindex'],
 }
 
 OFFTOPIC_CLASSES = ['ads']
@@ -57,6 +58,8 @@ P_AD_WORDS = [
 	'Love HuffPost',
 	'discounted subscription today',
 	'Just follow this link',
+	'Share on WeChat / 在微信上分享这篇文章',
+	'English version / 英文翻译'
 ]
 
 def _isOffTopic(attrs):
@@ -83,6 +86,11 @@ def _decompose(item):
 			print(item.name)
 		if _isOffTopic(item.attrs):
 			print(_isOffTopic(item.attrs))
+	if 'imageViewer' in str(item):
+		if item.name in OFFTOPIC_TAG:
+			print(item.name)
+		if _isOffTopic(item.attrs):
+			print(_isOffTopic(item.attrs))
 	item.decompose()
 
 def _decompseAds(soup):
